@@ -36,6 +36,17 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
   Pathname _patch;
   ByteCount _patch_size;
 
+  Offering::ScopedDemand _demandVerboseDownloadProgress;
+
+  void reportbegin() override
+  {
+    _demandVerboseDownloadProgress = Zypper::instance().runtimeData().scopedVerboseDownloadProgress.demand();
+  }
+  void reportend() override
+  {
+    _demandVerboseDownloadProgress.reset();
+  }
+
   // Dowmload delta rpm:
   // - path below url reported on start()
   // - expected download size (0 if unknown)
@@ -92,15 +103,15 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
     Zypper::instance().out().progressEnd("apply-delta", _label_apply_delta);
   }
 
-  void fillsRhs( TermLine & outstr_r, Zypper & zypper_r, Package::constPtr pkg_r )
+  void fillsRhs( TermLine & outstr_r, Zypper & zypper_r, Resolvable::constPtr res_r )
   {
     outstr_r.rhs << " (" << ++zypper_r.runtimeData().commit_pkg_current
-		 << "/" << zypper_r.runtimeData().commit_pkgs_total << ")";
-    if ( pkg_r )
+                 << "/" << zypper_r.runtimeData().commit_pkgs_total << ")";
+    if ( res_r )
     {
-      outstr_r.rhs << ", " << pkg_r->downloadSize().asString( 5, 3 ) << " "
-		   // TranslatorExplanation %s is package size like "5.6 M"
-		   << str::Format(_("(%s unpacked)")) % pkg_r->installSize().asString( 5, 3 );
+      outstr_r.rhs << ", " << res_r->downloadSize().asString( 5, 3 ) << "    "/* indent `/s)]` of download speed line following */;
+      // TranslatorExplanation %s is package size like "5.6 M"
+      // outstr_r.rhs << " " << str::Format(_("(%s unpacked)")) % pkg_r->installSize().asString( 5, 3 );
     }
   }
 
@@ -110,7 +121,7 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
 
     TermLine outstr( TermLine::SF_SPLIT | TermLine::SF_EXPAND );
     outstr.lhs << str::Format(_("In cache %1%")) % localfile_r.basename();
-    fillsRhs( outstr, zypper, asKind<Package>(res_r) );
+    fillsRhs( outstr, zypper, res_r );
     zypper.out().infoLine( outstr );
   }
 
@@ -125,11 +136,8 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
     Zypper & zypper = Zypper::instance();
 
     TermLine outstr( TermLine::SF_SPLIT | TermLine::SF_EXPAND );
-    outstr.lhs << str::Format(_("Retrieving %s %s-%s.%s"))
-        % kind_to_string_localized(_resolvable_ptr->kind(), 1)
-        % _resolvable_ptr->name()
-        % _resolvable_ptr->edition() % _resolvable_ptr->arch();
-    fillsRhs( outstr, zypper, asKind<Package>(resolvable_ptr) );
+    outstr.lhs << _("Retrieving:") << " " << _resolvable_ptr-> asUserString();
+    fillsRhs( outstr, zypper, resolvable_ptr );
 
     // temporary fix for bnc #545295
     if ( zypper.runtimeData().commit_pkg_current == zypper.runtimeData().commit_pkgs_total )
@@ -182,22 +190,22 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
     {
       switch ( el.first )
       {
-	case RpmDb::CHK_OK:
-	  if ( zypper.out().verbosity() >= Out::HIGH )	// quiet about good sigcheck unless verbose.
-	    msg << el.second << "\n";
-	  break;
-	case RpmDb::CHK_NOSIG:
-	   msg << ( (result == RpmDb::CHK_OK ? ColorContext::MSG_WARNING : ColorContext::MSG_ERROR ) << el.second ) << "\n";
-	   break;
-	case RpmDb::CHK_NOKEY:		// can't check
-	case RpmDb::CHK_NOTFOUND:
-	  msg << ( ColorContext::MSG_WARNING << el.second ) << "\n";
-	  break;
-	case RpmDb::CHK_FAIL:		// failed check
-	case RpmDb::CHK_NOTTRUSTED:
-	case RpmDb::CHK_ERROR:
-	  msg << ( ColorContext::MSG_ERROR << el.second ) << "\n";
-	  break;
+        case RpmDb::CHK_OK:
+          if ( zypper.out().verbosity() >= Out::HIGH )	// quiet about good sigcheck unless verbose.
+            msg << el.second << "\n";
+          break;
+        case RpmDb::CHK_NOSIG:
+           msg << ( (result == RpmDb::CHK_OK ? ColorContext::MSG_WARNING : ColorContext::MSG_ERROR ) << el.second ) << "\n";
+           break;
+        case RpmDb::CHK_NOKEY:		// can't check
+        case RpmDb::CHK_NOTFOUND:
+          msg << ( ColorContext::MSG_WARNING << el.second ) << "\n";
+          break;
+        case RpmDb::CHK_FAIL:		// failed check
+        case RpmDb::CHK_NOTTRUSTED:
+        case RpmDb::CHK_ERROR:
+          msg << ( ColorContext::MSG_ERROR << el.second ) << "\n";
+          break;
       }
     }
 
@@ -205,7 +213,7 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
     {
       const std::string & msgstr( msg.str() );
       if ( ! msgstr.empty() )
-	zypper.out().info( msg );
+        zypper.out().info( msg );
       return;
     }
 
@@ -217,22 +225,22 @@ struct DownloadResolvableReportReceiver : public callback::ReceiveReport<repo::D
       std::string err( str::Str() << pkg->asUserString() << ": " << _("Signature verification failed") << " " << result );
       switch ( result )
       {
-	case RpmDb::CHK_OK:
-	  // Can't happen; already handled above
-	  break;
+        case RpmDb::CHK_OK:
+          // Can't happen; already handled above
+          break;
 
-	case RpmDb::CHK_NOKEY:		// can't check
-	case RpmDb::CHK_NOTFOUND:
-	case RpmDb::CHK_NOSIG:
-	  msg << ( ColorContext::MSG_WARNING << err ) << "\n";
-	  break;
+        case RpmDb::CHK_NOKEY:		// can't check
+        case RpmDb::CHK_NOTFOUND:
+        case RpmDb::CHK_NOSIG:
+          msg << ( ColorContext::MSG_WARNING << err ) << "\n";
+          break;
 
-	case RpmDb::CHK_FAIL:		// failed check
-	case RpmDb::CHK_ERROR:
-	case RpmDb::CHK_NOTTRUSTED:
-	default:
-	  msg << ( ColorContext::MSG_ERROR << err ) << "\n";
-	  break;
+        case RpmDb::CHK_FAIL:		// failed check
+        case RpmDb::CHK_ERROR:
+        case RpmDb::CHK_NOTTRUSTED:
+        default:
+          msg << ( ColorContext::MSG_ERROR << err ) << "\n";
+          break;
       }
       msg << _("Accepting package despite the error.") << " (--no-gpg-checks)" << "\n";
       userData_r.set( "Action", IGNORE );
@@ -294,7 +302,7 @@ struct ProgressReportReceiver  : public callback::ReceiveReport<ProgressReport>
     Zypper::instance().out().progressEnd(
         str::numstring(data.numericId()),
         data.name(),
-	!( last == 100 || last == -1 )
+        !( last == 100 || last == -1 )
     );
   }
 };
