@@ -3,7 +3,7 @@
 #include <iostream>
 
 #ifndef INCLUDE_TESTSETUP_WITHOUT_BOOST
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 using boost::unit_test::test_case;
 #endif
 
